@@ -7,7 +7,7 @@ import subprocess
 
 from .daemon import Daemon
 from .utils.logger import setup_logging
-from .config import DAEMON_VERSION, LOG_FILE_PATH
+from .config import DAEMON_VERSION, LOG_FILE_PATH, COMMANDS
 
 if sys.platform.startswith('win32'):
     from .channel.win.client import Client
@@ -15,10 +15,29 @@ else:
     from .channel.unix.client import Client
 
 parser = argparse.ArgumentParser(description='Pywalfox - Native messaging host')
-parser.add_argument('action', nargs='?', default=None, help='available options are setup, update, daemon, log and uninstall')
-parser.add_argument('--verbose', dest='verbose', action='store_true', help='runs the daemon in verbose mode with debugging output')
-parser.add_argument('-p', '--print', dest='print_mode', action='store_true', help='prints the debugging output instead of writing to logfile')
-parser.add_argument('-v', '--version', dest='version', action='store_true', help='displays the current version of the daemon')
+setup_group = parser.add_argument_group('install/uninstall')
+start_group = parser.add_argument_group('start')
+parser.add_argument('action',
+        nargs='?',
+        default=None,
+        metavar='ACTION',
+        help='available actions are install, uninstall, start, update, log, dark, light and auto')
+parser.add_argument('-v', '--version',
+        dest='version',
+        action='store_true',
+        help='displays the current version of the daemon')
+start_group.add_argument('-p', '--print',
+        dest='print_mode',
+        action='store_true',
+        help='writes debugging output from the native messaging host to stdout')
+start_group.add_argument('--verbose',
+        dest='verbose',
+        action='store_true',
+        help='runs the native messaging host in verbose mode')
+setup_group.add_argument('-g', '--global',
+        dest='global_install',
+        action='store_true',
+        help='installs/uninstalls the native host manifest globally')
 
 def get_python_version():
     """Gets the current python version and checks if it is supported."""
@@ -32,14 +51,31 @@ def get_python_version():
 
     return python_version
 
-def send_update_action():
-    """Sends the update command to the socket server."""
+def send_client_command(message):
+    """
+    Sends a message to the socket server.
+
+    :param message str: the message to send
+    """
     client = Client()
 
     for host in client.hosts:
         connected = client.connect(host)
         if connected is True:
-            client.send_message('update')
+            client.send_message(message)
+
+def send_update_action():
+    """Sends an update command to the addon, triggering a refetch of colors"""
+    send_client_command(COMMANDS['UPDATE'])
+
+def send_theme_mode_dark():
+    send_client_command(COMMANDS['THEME_MODE_DARK'])
+
+def send_theme_mode_light():
+    send_client_command(COMMANDS['THEME_MODE_LIGHT'])
+
+def send_theme_mode_auto():
+    send_client_command(COMMANDS['THEME_MODE_AUTO'])
 
 def open_log_file():
     """Opens the daemon log file in an editor."""
@@ -73,7 +109,19 @@ def handle_args(args):
         send_update_action()
         sys.exit(0)
 
-    if args.action == 'daemon':
+    if args.action == 'dark':
+        send_theme_mode_dark()
+        sys.exit(0)
+
+    if args.action == 'light':
+        send_theme_mode_light()
+        sys.exit(0)
+
+    if args.action == 'auto':
+        send_theme_mode_auto()
+        sys.exit(0)
+
+    if args.action == 'start':
         setup_logging(args.verbose, args.print_mode)
         run_daemon()
 
@@ -81,14 +129,14 @@ def handle_args(args):
         open_log_file()
         sys.exit(0)
 
-    if args.action == 'setup':
+    if args.action == 'install':
         from pywalfox.install import start_setup
-        start_setup(True)
+        start_setup(args.global_install)
         sys.exit(0)
 
     if args.action == 'uninstall':
         from pywalfox.install import start_uninstall
-        start_uninstall(True)
+        start_uninstall(args.global_install)
         sys.exit(0)
 
     # If no action was specified
